@@ -94,6 +94,12 @@ set_config <- function(svc, cfgs = list()) {
   cfgs <- update_optional_config_parameter(cfgs, cfgs$credentials$profile)
   config <- populate(cfgs, shape)
   config$credentials <- as.environment(config$credentials)
+  if (nchar(config$region) == 0) {
+    config$region <- get_region(config[["credentials"]][["profile"]])
+  }
+  if (!is.null(config$region) || nchar(config$region) > 0) {
+    config$partition_name <- set_partition_name(config$region)
+  }
   svc$.internal <- list(config = config)
   set_paws_vendor()
   return(svc)
@@ -102,14 +108,8 @@ set_config <- function(svc, cfgs = list()) {
 set_paws_vendor <- function() {
   where <- topenv(parent.frame(n = 2))
   pkg_name <- get0(".packageName", where, inherits = FALSE)
-  if (
-    !is.null(pkg_name) &&
-      startsWith(pkg_name, "paws.") &&
-      pkg_name != "paws.common"
-  ) {
-    vendor <- (
-      if (packageVersion(pkg_name) >= numeric_version("0.8.0")) "boto" else "js"
-    )
+  if (!is.null(pkg_name) && startsWith(pkg_name, "paws.") && pkg_name != "paws.common") {
+    vendor <- (if (packageVersion(pkg_name) >= numeric_version("0.8.0")) "boto" else "js")
     vendor_cache[["vendor"]] <- vendor
   }
 }
@@ -204,17 +204,13 @@ get_iam_role <- function() {
 get_instance_metadata <- function(query_path = "") {
   token_ttl <- "21600" # same approach as in boto3: https://github.com/boto/botocore/blob/master/botocore/utils.py#L376
   # Do not get metadata when the disabled setting is on.
-  if (
-    trimws(tolower(get_env("AWS_EC2_METADATA_DISABLED"))) %in% c("true", "1")
-  ) {
+  if (trimws(tolower(get_env("AWS_EC2_METADATA_DISABLED"))) %in% c("true", "1")) {
     return(NULL)
   }
   # Get token timeout for IMDSv2 tokens
   token <- "" # Token to be used in case of more secure IMDSv2 authentication
   # try IMDSv2  (more information): https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html
-  metadata_token_url <- file.path(
-    "http://169.254.169.254/latest/api/token"
-  )
+  metadata_token_url <- file.path("http://169.254.169.254/latest/api/token")
   metadata_token_request <- new_http_request(
     "PUT",
     metadata_token_url,
@@ -229,18 +225,12 @@ get_instance_metadata <- function(query_path = "") {
       NULL
     }
   )
-  if (
-    !is.null(metadata_token_response) &&
-      metadata_token_response$status_code == 200
-  ) {
+  if (!is.null(metadata_token_response) && metadata_token_response$status_code == 200) {
     if (length(metadata_token_response[["body"]]) > 0) {
       token <- rawToChar(metadata_token_response[["body"]])
     }
   }
-  metadata_url <- file.path(
-    "http://169.254.169.254/latest/meta-data",
-    query_path
-  )
+  metadata_url <- file.path("http://169.254.169.254/latest/meta-data", query_path)
   if (token != "") {
     metadata_request <- new_http_request(
       "GET",
@@ -249,11 +239,7 @@ get_instance_metadata <- function(query_path = "") {
       header = c("X-aws-ec2-metadata-token" = token)
     )
   } else {
-    metadata_request <- new_http_request(
-      "GET",
-      metadata_url,
-      timeout = 1
-    )
+    metadata_request <- new_http_request("GET", metadata_url, timeout = 1)
   }
   metadata_response <- tryCatch(
     {
@@ -327,10 +313,7 @@ get_region <- function(profile = "") {
   }
   region <- check_config_file_region(profile)
 
-  if (is.null(region)) {
-    region <- "aws-global"
-  }
-  return(region)
+  return(region %||% "")
 }
 
 # Get Endpoint for Service
@@ -364,9 +347,7 @@ check_config_file_endpoint <- function(profile = "", service_id = "") {
   if (is.null(service_name <- profile[["services"]])) {
     return(profile[["endpoint_url"]])
   }
-  profile_service <- config_values[[paste("services", service_name)]][[
-    service_id
-  ]]
+  profile_service <- config_values[[paste("services", service_name)]][[service_id]]
   if (is.null(profile_service)) {
     return(profile[["endpoint_url"]])
   }
@@ -415,12 +396,7 @@ get_web_identity_token_file <- function(web_identity_token_file = "") {
 
 # Get the Web Identity Token from reading the token file
 get_web_identity_token <- function(web_identity_token_file = "") {
-  return(
-    readLines(
-      get_web_identity_token_file(web_identity_token_file),
-      warn = FALSE
-    )
-  )
+  return(readLines(get_web_identity_token_file(web_identity_token_file), warn = FALSE))
 }
 
 # Check if sts_regional_endpoint is present in config file
@@ -456,9 +432,7 @@ get_sts_regional_endpoint <- function(profile = "") {
   return(sts_regional_endpoint %||% "")
 }
 
-.optional_config_parameter <- list(
-  "sts_regional_endpoint" = get_sts_regional_endpoint
-)
+.optional_config_parameter <- list("sts_regional_endpoint" = get_sts_regional_endpoint)
 
 # Ensures config is built correctly from service parameters
 build_config <- function(cfg) {
@@ -478,9 +452,7 @@ build_config <- function(cfg) {
       for (credentails_name in credentails_names) {
         if (credentails_name == "creds") {
           for (cred_name in cred_names) {
-            creds[[cred_name]] <- cfg[[cfg_name]][[credentails_name]][[
-              cred_name
-            ]]
+            creds[[cred_name]] <- cfg[[cfg_name]][[credentails_name]][[cred_name]]
           }
           credentials[[credentails_name]] <- add_list(creds)
         } else {
