@@ -11,11 +11,7 @@ TIME_FORMAT <- "%Y%m%dT%H%M%SZ" # "20060102T150405Z"
 SHORT_TIME_FORMAT <- "%Y%m%d" # "20060102"
 EMPTY_STRING_SHA256 <- "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855"
 
-IGNORED_HEADERS <- c(
-  "Authorization",
-  "User-Agent",
-  "X-Amzn-Trace-Id"
-)
+IGNORED_HEADERS <- c("Authorization", "User-Agent", "X-Amzn-Trace-Id")
 
 REQUIRED_SIGNED_HEADERS <- c(
   "Cache-Control",
@@ -103,9 +99,7 @@ v4_sign_request_handler <- function(request) {
   return(sign_sdk_request_with_curr_time(request))
 }
 
-sign_sdk_request_with_curr_time <- function(request,
-                                            curr_time_fn = now,
-                                            opts = NULL) {
+sign_sdk_request_with_curr_time <- function(request, curr_time_fn = now, opts = NULL) {
   region <- request$client_info$signing_region
   if (region == "") {
     region <- request$config$region
@@ -134,9 +128,14 @@ sign_sdk_request_with_curr_time <- function(request,
   }
 
   request$http_request <- sign_with_body(
-    v4, request$http_request, request$body,
-    name, region, request$expire_time,
-    request$expire_time > 0, signing_time
+    v4,
+    request$http_request,
+    request$body,
+    name,
+    region,
+    request$expire_time,
+    request$expire_time > 0,
+    signing_time
   )
 
   # set headers for anonymous credentials
@@ -149,8 +148,16 @@ sign_sdk_request_with_curr_time <- function(request,
   return(request)
 }
 
-sign_with_body <- function(signer, request, body, service, region,
-                           expire_time, is_presigned, signing_time) {
+sign_with_body <- function(
+  signer,
+  request,
+  body,
+  service,
+  region,
+  expire_time,
+  is_presigned,
+  signing_time
+) {
   curr_time_fn <- signer$curr_time_fn
   if (is.null(curr_time_fn)) {
     curr_time_fn <- now
@@ -266,13 +273,12 @@ build_context <- function(ctx, disable_header_hoisting) {
   unsigned_headers <- ctx$request$header
   if (ctx$is_presigned) {
     if (!disable_header_hoisting) {
-      for (header in names(unsigned_headers)) {
-        if (startsWith(header, "X-Amz-") & !startsWith(header, "X-Amz-Meta-") &
-          !(header %in% REQUIRED_SIGNED_HEADERS)) {
-          ctx$query[[header]] <- unsigned_headers[[header]]
-          unsigned_headers[[header]] <- NULL
-        }
-      }
+      header <- names(unsigned_headers)
+      found <- (startsWith(header, "X-Amz-") &
+        !startsWith(header, "X-Amz-Meta-") &
+        !(header %in% REQUIRED_SIGNED_HEADERS))
+      ctx$query[header[found]] <- unsigned_headers[header[found]]
+      unsigned_headers[header[found]] <- NULL
     }
   }
   ctx <- build_canonical_headers(ctx, unsigned_headers, IGNORED_HEADERS)
@@ -285,12 +291,16 @@ build_context <- function(ctx, disable_header_hoisting) {
   # log_debug("Signature:\n%s", ctx$signature)
   if (ctx$is_presigned) {
     query <- ctx$request$url$raw_query
-    ctx$request$url$raw_query <- sprintf(
-      "%s&X-Amz-Signature=%s", query, ctx$signature
-    )
+    ctx$request$url$raw_query <- sprintf("%s&X-Amz-Signature=%s", query, ctx$signature)
   } else {
     authorization <- paste(
-      paste0(AUTH_HEADER_PREFIX, " Credential=", ctx$cred_values$access_key_id, "/", ctx$credential_string),
+      paste0(
+        AUTH_HEADER_PREFIX,
+        " Credential=",
+        ctx$cred_values$access_key_id,
+        "/",
+        ctx$credential_string
+      ),
       paste0("SignedHeaders=", ctx$signed_headers),
       paste0("Signature=", ctx$signature),
       sep = ", "
@@ -341,13 +351,9 @@ sha256 <- function(x) {
 build_body_digest <- function(ctx) {
   hash <- get_element(ctx$request$header, "X-Amz-Content-Sha256")
   if (hash == "") {
-    include_sha256_header <- (
-      ctx$unsigned_payload ||
-        ctx$service_name %in% c("s3", "s3-object-lambda", "glacier")
-    )
-    s3_presign <- (
-      ctx$is_presigned && ctx$service_name %in% c("s3", "s3-object-lambda")
-    )
+    include_sha256_header <- (ctx$unsigned_payload ||
+      ctx$service_name %in% c("s3", "s3-object-lambda", "glacier"))
+    s3_presign <- (ctx$is_presigned && ctx$service_name %in% c("s3", "s3-object-lambda"))
     if (ctx$unsigned_payload || s3_presign) {
       hash <- "UNSIGNED-PAYLOAD"
       include_sha256_header <- !s3_presign
@@ -399,7 +405,12 @@ build_canonical_headers <- function(ctx, header, ignored_headers) {
 
 build_canonical_string <- function(ctx) {
   if (!is.null(ctx$query)) {
-    ctx$request$url$raw_query <- gsub("+", "%20", build_query_string(ctx$query), fixed = T)
+    ctx$request$url$raw_query <- gsub(
+      "+",
+      "%20",
+      build_query_string(ctx$query),
+      fixed = T
+    )
   }
 
   uri <- get_uri_path(ctx$request$url)
